# InvPlaybookDue

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**_date** | **datetime** |  | [optional] 
**in_task_id** | **str** |  | [optional] 
**inv_id** | **str** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


